import { Component, Input, OnInit, SimpleChanges } from '@angular/core';
import { ListService } from '../list.service';

import { ActivatedRoute } from '@angular/router';

import { IPerson, personalCodeStamper } from '../person';

import { faSort } from '@fortawesome/free-solid-svg-icons';
import { faSortUp } from '@fortawesome/free-solid-svg-icons';
import { faSortDown } from '@fortawesome/free-solid-svg-icons';

// This component is for listing the people

@Component({
  selector: 'app-list',
  styleUrls: ['./list.component.styl'],
  templateUrl: './list.component.html',
})
export class ListComponent implements OnInit {
  public people: IPerson[];
  private selected: IPerson;

  public sortBy: string;
  public sortDir = 0;

  public faSort = faSort;
  public faSortUp = faSortUp;
  public faSortDown = faSortDown;

  public page = 1;
  public pages = 10;
  private perPage = 10;

  constructor(private route: ActivatedRoute, private listService: ListService) { }

  public ngOnInit(): void {
    this.route.queryParams
      .subscribe((params) => {
        this.page = +(params.page || 1);
      });

    this.getList();
  }

  public get startIndex(): number {
    // First argument to array slicer
    return (this.page - 1) * this.perPage;
  }

  public get endIndex(): number {
    // Second argument to array slicer
    return this.startIndex + this.perPage;
  }

  public setSort(field: string): void {
    // Reset the sorting if it is a new field
    if (this.sortBy !== field) {
      this.sortDir = 0;
    }

    this.sortBy = field;
    this.sortDir++;

    // Loop back to descending sort
    if (this.sortDir === 2) {
      this.sortDir = -1;
    }
  }

  private getList(): void {
    this.listService.getList().subscribe(
      (data) => {
        this.people = data.list;
        // Calculate date of birth from personal codes.
        this.people.forEach((p) => p.dob = personalCodeStamper(p.personal_code));
      });
  }

  private selectPerson(person: IPerson): void {
    // Select a person to show the details of
    if (this.selected === person) {
      this.selected = null;
      return;
    }
    this.selected = person;
  }
}
